function [ locErrors, locErrorsNorm, detectRate ] = OpticDiscLocEval_Messidor( retDir, maskDir )
% Evaluate accuracy on detecting the optic disc center on Messidor Database.

% locErrors: Vector with euclidean distance between estimated and real
% center
% locErrorsNorm: Vector with normalized distance between estimated and real
% center

% retDir: Path to the folder with Messidor images 
% maskDir: Path to the folder with Messidor ground truth masks

warning('OFF', 'all')

imgFiles = dir(fullfile(retDir, '*.tif'));
maskFiles = dir(fullfile(maskDir, '*.tif'));

locErrors = zeros(1, length(imgFiles));
locErrorsNorm = zeros(1, length(imgFiles));
detectRate = zeros(1, length(imgFiles));
for i = 1:length(imgFiles)
    i
    retinalImage = imread(fullfile(retDir, imgFiles(i).name));
    nrows = size(retinalImage, 1);
    ncols = size(retinalImage, 2);
    % The original image is scaled so that its FOV diameter becomes equal to 540 pixels
    if nrows == 960
        scaleFactor = 0.5960;    
    elseif nrows == 1488
        scaleFactor = 0.3930;
    elseif nrows == 1536
        scaleFactor = 0.3730;
    else
        error('Unexpected image dimensions')
    end
    retinalImage1 = imresize(retinalImage, scaleFactor);
    nrows1 = size(retinalImage1, 1);
    ncols1 = size(retinalImage1, 2);
    % Get estimated optic disc center
    [ xCenter, yCenter ] = OpticDiscLocUsingFilters(retinalImage1);
    % The coordinates are rescaled to their original size
    xCenter = round(xCenter/(ncols1/ncols));   
    yCenter = round(yCenter/(nrows1/nrows));
    truthMask = imread(fullfile(maskDir, maskFiles(i).name));
    truthMask = imfill(truthMask, 'holes');
    truthMaskArea = sum(sum(truthMask == 255));
    eqRadius = sqrt(truthMaskArea/pi);
    % Get the ground truth center and calculate error
    [ y, x ] = find(truthMask);
    xTruth = mean(x);
    yTruth = mean(y);
    locErrors(i) = sqrt((xCenter - xTruth).^2 + (yCenter - yTruth).^2);
    locErrorsNorm(i) = sqrt((xCenter - xTruth).^2 + (yCenter - yTruth).^2)/eqRadius;
    detectRate(i) = truthMask(yCenter, xCenter);

end

end