function [ locErrors, locErrorsNorm, detectRate ] = OpticDiscLocEval_ONHSD( retDir, maskDir )
% Evaluate accuracy on detecting the optic disc center on ONHSD Database.

% locErrors: Vector with euclidean distance between estimated and real
% center
% locErrorsNorm: Vector with normalized distance between estimated and real
% center

% retDir: Path to the folder with ONHSD images 
% maskDir: Path to the folder with ONHSD ground truth masks

warning('OFF', 'all')

imgFiles = dir(fullfile(retDir, '*.bmp'));

locErrors = zeros(1, length(imgFiles));
locErrorsNorm = zeros(1, length(imgFiles));
detectRate = zeros(1, length(imgFiles));
for i = 1:length(imgFiles)
    i
    retinalImage = imread(fullfile(retDir, imgFiles(i).name));
    [pathstr, name, ext] = fileparts(imgFiles(i).name);
    % The original image has approximately a FOV diameter equal to 540 pixels
    % No resize operation needed
    
    % Get estimated optic disc center
    [ xCenter, yCenter ] = OpticDiscLocUsingFilters(retinalImage);
    load(fullfile(maskDir, strcat(name, '.mat')));
    truthMask = imfill(mask, 'holes');
    truthMaskArea = sum(sum(truthMask == 1));
    eqRadius = sqrt(truthMaskArea/pi);
    % Get the ground truth center and calculate error
    [ y, x ] = find(truthMask);
    xTruth = mean(x);
    yTruth = mean(y);
    locErrors(i) = sqrt((xCenter - xTruth).^2 + (yCenter - yTruth).^2);
    locErrorsNorm(i) = sqrt((xCenter - xTruth).^2 + (yCenter - yTruth).^2)/eqRadius;
    detectRate(i) = truthMask(yCenter, xCenter);
end

end