function [ JC, DC, MAD ] = OpticDiscSegEval_Messidor( retDir, maskDir )
% Evaluate accuracy on optic disc segmentation on Messidor Database.

% JC: Vector with Jaccard coefficient values
% DC: Vector with Dice coefficient values
% MAD: Vector with Mean Average Distance values

% retDir: Path to the folder with Messidor images 
% maskDir: Path to the folder with Messidor ground truth masks

warning('OFF', 'all')

imgFiles = dir(fullfile(retDir, '*.tif'));
maskFiles = dir(fullfile(maskDir, '*.tif'));

JC = zeros(1, length(imgFiles));
DC = zeros(1, length(imgFiles));
MAD = zeros(1, length(imgFiles));
for i = 1:length(imgFiles)
    i
    retinalImage = imread(fullfile(retDir, imgFiles(i).name));

    truthMask = imread(fullfile(maskDir, maskFiles(i).name));
    truthMask = imfill(truthMask, 'holes');
    nrows = size(retinalImage, 1);
    ncols = size(retinalImage, 2);
    % The original image is scaled so that its FOV diameter becomes equal to 540 pixels
    if nrows == 960
        scaleFactor = 0.5960;    
    elseif nrows == 1488
        scaleFactor = 0.3930;
    elseif nrows == 1536
        scaleFactor = 0.3730;
    else
        error('Unexpected image dimensions')
    end
    retinalImage1 = imresize(retinalImage, scaleFactor);
    % Get estimated optic disc center
    [ xCenter, yCenter ] = OpticDiscLocUsingFilters(retinalImage1);
    nrows1 = size(retinalImage1, 1);
    ncols1 = size(retinalImage1, 2);
    xCenter = round(xCenter/(ncols1/ncols));
    yCenter = round(yCenter/(nrows1/nrows));
    % Get optic disc segmentation
    [ opticDiscMask ] = OpticDiscSegUsingCircularSections(retinalImage, xCenter, yCenter);
    [ JCi, DCi, MADi ] = evaluateRetino( opticDiscMask, truthMask );
    JC(i) = JCi;
    DC(i) = DCi;
    MAD(i) = MADi;
end

end