function [ JC, DC, MAD ] = OpticDiscSegEval_ONHSD( retDir, maskDir )
% Evaluate accuracy on optic disc segmentation on ONHSD Database.

% JC: Vector with Jaccard coefficient values
% DC: Vector with Dice coefficient values
% MAD: Vector with Mean Average Distance values

% retDir: Path to the folder with ONHSD images 
% maskDir: Path to the folder with ONHSD ground truth masks

warning('OFF', 'all')

imgFiles = dir(fullfile(retDir, '*.bmp'));

JC = zeros(1, length(imgFiles));
DC = zeros(1, length(imgFiles));
MAD = zeros(1, length(imgFiles));
for i = 1:length(imgFiles)
    i
    [pathstr, name, ext] = fileparts(imgFiles(i).name);
    retinalImage = imread(fullfile(retDir, imgFiles(i).name));
    
    load(fullfile(maskDir, strcat(name, '.mat')));
    truthMask = imfill(mask, 'holes');
    % The original image has approximately a FOV diameter equal to 540 pixels
    % No resize operation needed
    
    % Get estimated optic disc center
    [ xCenter, yCenter ] = OpticDiscLocUsingFilters(retinalImage);
    % Get optic disc segmentation
    [ opticDiscMask ] = OpticDiscSegUsingCircularSections(retinalImage, xCenter, yCenter);
    [ JCi, DCi, MADi ] = evaluateRetino( opticDiscMask, truthMask );
    JC(i) = JCi;
    DC(i) = DCi;
    MAD(i) = MADi;
end

end