function [ JC, DC, MAD ] = evaluateRetino( gtMask, segMask )
% Evaluate JC, DICE and MAD values between a retinal ground truth image 
%  and a segmentation.

% JC: Jaccard coefficient
% DC: Dice coefficient
% MAD: Mean Average Distance value

% gtMask: ground truth mask
% segMask: mask obtained by the segmentation method

[imageX, imageY] = size(gtMask);
if imageX~=size(segMask,1) || imageY~=size(segMask,2)
    error('The sizes of the two comparing images must be the same.');
end
if (max(max(gtMask)) == 0)
    error('gtMask does not contain any mask value');
end
if (max(max(segMask)) == 0)
    error('segMask does not contain any mask value');
end
    
[nrows,ncols] = size(gtMask);

% MAD 
image1perim = bwperim(gtMask);
image2perim = bwperim(segMask);

[rowimg1, colimg1] = find(image1perim);
[rowimg2, colimg2] = find(image2perim);

nele1 = size(rowimg1,1);
nele2 = size(rowimg2,1);

distDir1 = 0;
for i=1:nele1
    coordX1 = rowimg1(i);
    coordY1 = colimg1(i);
    dist  = sqrt(((rowimg2 - coordX1) .^ 2)+((colimg2 - coordY1) .^ 2));
    [valMin, coordMin] = min(dist);
    distDir1 = distDir1 + valMin;
end
distDir1 = distDir1/nele1;

distDir2 = 0;
for i=1:nele2
    coordX2 = rowimg2(i);
    coordY2 = colimg2(i);
    dist  = sqrt(((rowimg1 - coordX2) .^ 2)+((colimg1 - coordY2) .^ 2));
    [valMin, coordMin] = min(dist);
    distDir2 = distDir2 + valMin;
end
distDir2 = distDir2/nele2;
MAD = (distDir1 + distDir2)/2;

% JC
gtMask = gtMask + 1;
segMask = segMask + 1;
segmentcount1=max(max(gtMask));
segmentcount2=max(max(segMask));

% Compute the count matrix
n=zeros(segmentcount1,segmentcount2);
for i=1:nrows
    for j=1:ncols
        u=gtMask(i,j);
        v=segMask(i,j);
        n(u,v)=n(u,v)+1;
    end;
end;
N = sum(sum(n));
n_u=sum(n,2);
n_v=sum(n,1);
overlap = n./(n_u*ones(1,length(n_v)) + ones(length(n_u),1)*n_v - n);
[maxValue maxPos] = max(overlap,[],2);
JC = maxValue(2);

% DC
dice1 = (2.*n)./(n_u*ones(1,length(n_v)) + ones(length(n_u),1)*n_v);
[maxValue maxPos] = max(dice1,[],2);
DC = maxValue(2);

end

